@@ -76,7 +76,7 @@ class account():
             print "Establishing api for " + self.accountdata.servicename + " using oauth"
             self.api = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, self.accountdata.access_token)
         if (self.api == None):
-            print "Failed to establish api for " + +self.accountdata.servicename
+            print "Failed to establish api for " + self.accountdata.servicename
             return False
         else:
             print "Connection working ok"
