@@ -846,58 +846,64 @@ class WitterUI():
                                     print "excluding self from reply all"
                                 else:
                                     self.controller.reply_all = self.controller.reply_all + " " + user
-                                if (user != name):
-
-                                    b = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                                    b.set_title('Follow')
-                                    b.set_value(user)
-                                    b.connect("clicked", self.controller.activeAccount.FollowUser, user)
-                                    hbox1.pack_start(b, expand=True)
-                                    b2 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
-
-                                    b2.set_title(user)
-                                    b2.connect("clicked", self.controller.tweetAtUser, user)
-                                    hbox1.pack_start(b2, expand=True)
-                                    b3 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
-
-                                    b3.set_title('History')
-                                    b3.set_value(user)
-                                    b3.connect("clicked", self.controller.showHist, user)
-                                    hbox1.pack_start(b3, expand=True)
-
-
+                         #       if (user != name):
+#
+ #                                   b = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+  #                                                    hildon.BUTTON_ARRANGEMENT_VERTICAL)
+   #                                 b.set_title('Follow')
+    #                                b.set_value(user)
+     #                               b.connect("clicked", self.controller.activeAccount.FollowUser, user)
+      #                              hbox1.pack_start(b, expand=True)
+       #                             b2 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+ #                                                     hildon.BUTTON_ARRANGEMENT_VERTICAL)
+##
+  #                                  b2.set_title(user)
+   #                                 b2.connect("clicked", self.controller.tweetAtUser, user)
+    #                                hbox1.pack_start(b2, expand=True)
+     #                               b3 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+      #                                                hildon.BUTTON_ARRANGEMENT_VERTICAL)
+#
+ #                                   b3.set_title('History')
+  #                                  b3.set_value(user)
+   #                                 b3.connect("clicked", self.controller.showHist, user)
+    #                                hbox1.pack_start(b3, expand=True)
+#
+#
                     #rect = self.treeview.get_background_area(item, self.tvctweet)
                     #x, y = self.treeview.convert_bin_window_to_tree_coords(rect.x, rect.y)
                 #only provide a follow button if we aren't in our own timeline (in which case we're already following
-                curView = self.getCurrentView()
-                if (curView != self.TIMELINE_VIEW):
-                    followButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-                                                          hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                    followButton.set_title('Follow')
-                    followButton.set_value(name)
-                    followButton.connect("clicked", self.controller.activeAccount.FollowUser, name)
-                    hbox2.pack_start(followButton, expand=True)
-                unfollowButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                unfollowButton.set_title('unFollow')
-                unfollowButton.set_value(name)
-                unfollowButton.connect("clicked", self.controller.activeAccount.UnFollowUser, name)
-                hbox2.pack_start(unfollowButton, expand=True)
-                histButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                histButton.set_title('History')
-                histButton.set_value(name)
-                histButton.connect("clicked", self.controller.showHist, name)
-                hbox2.pack_start(histButton, expand=True)
+#                curView = self.getCurrentView()
+ #               if (curView != self.TIMELINE_VIEW):
+  #                  followButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+   #                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
+    #                followButton.set_title('Follow')
+     #               followButton.set_value(name)
+      #              followButton.connect("clicked", self.controller.activeAccount.FollowUser, name)
+       #             hbox2.pack_start(followButton, expand=True)
+        #        unfollowButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+         #                                             hildon.BUTTON_ARRANGEMENT_VERTICAL)
+          #      unfollowButton.set_title('unFollow')
+           #     unfollowButton.set_value(name)
+            #    unfollowButton.connect("clicked", self.controller.activeAccount.UnFollowUser, name)
+             #   hbox2.pack_start(unfollowButton, expand=True)
+#                histButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+ #                                                     hildon.BUTTON_ARRANGEMENT_VERTICAL)
+  #              histButton.set_title('History')
+   #             histButton.set_value(name)
+    #            histButton.connect("clicked", self.controller.showHist, name)
+     #           hbox2.pack_start(histButton, expand=True)
 
-                atuser = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+ #               atuser = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+  #                                                    hildon.BUTTON_ARRANGEMENT_VERTICAL)
+   #             atuser.set_title(name)
+    #            atuser.connect("clicked", self.controller.tweetAt, name)
+     #           hbox2.pack_start(atuser, expand=True)
+
+                userOptions = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                atuser.set_title(name)
-                atuser.connect("clicked", self.controller.tweetAt, name)
-                hbox2.pack_start(atuser, expand=True)
+                userOptions.set_title("Mentioned Users")
+                userOptions.connect("clicked", self.buildUserActionMenu)
+                hbox2.pack_start(userOptions, expand=True)
 
                 translate = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
@@ -925,6 +931,121 @@ class WitterUI():
         win.add(pannedArea)
         win.show_all()
 
+    def buildUserActionMenu(self, widget, *args):
+        #first hide the other controls
+        print "building stacked menu for user actions"
+        win = hildon.StackableWindow()
+        win.set_title("User Options")
+        pannedArea = hildon.PannableArea()
+        hbox1 = gtk.HBox()
+        hboxTweet = gtk.HBox()
+        vbox0 = gtk.VBox()
+        vbox1 = gtk.VBox()
+        vbox2 = gtk.VBox()
+        vbox3 = gtk.VBox()
+        #empty the dynamic buttons
+
+        #add avatar image and the tweet selected
+        # then all the associated action buttons
+        #standard buttons
+        #reply
+
+        #get the selection
+        treeselection = self.treeview.get_selection()
+        select1, select2 = treeselection.get_selected_rows()
+        #entry1, entry2 = self.treeview.get_selection().get_selected()
+        #we might one day have more than on element selected, for now we get 1 row
+        try:
+            #we want to scroll to the right place in pannable area, *after* we've shown conrolls
+            #so the x/y need to be in the right scope
+            selectedItem = None
+            if select2 != None:
+
+                for item in select2[0]:
+                    #bring the selected item to the top of the view
+
+                    #we want to access field 2 (0,1,2) which has our Tweet in it
+                    entry = select1.get_value(select1.get_iter(item), 2)
+                    #and we might as well list the person who provided the url
+                    name = select1.get_value(select1.get_iter(item), 0)
+
+
+                    id = select1.get_value(select1.get_iter(item), 4)
+                    selectedItem = item
+                    follow = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                    follow.set_title('Follow')
+                    follow.set_value(name)
+                    follow.connect("clicked", self.controller.activeAccount.FollowUser, name)
+                    vbox0.pack_start(follow, expand=False)
+                    unfollowButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                    unfollowButton.set_title('unFollow')
+                    unfollowButton.set_value(name)
+                    unfollowButton.connect("clicked", self.controller.activeAccount.UnFollowUser, name)
+                    vbox1.pack_start(unfollowButton, expand=False)
+                    tweetat = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+
+                    tweetat.set_title(name)
+                    tweetat.connect("clicked", self.controller.tweetAtUser, name)
+                    vbox2.pack_start(tweetat, expand=False)
+                    hist = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+
+                    hist.set_title('History')
+                    hist.set_value(name)
+                    hist.connect("clicked", self.controller.showHist, name)
+                    vbox3.pack_start(hist, expand=False)
+                    if re.search("@", entry):
+                        L = string.split(entry)
+                        for word in L :
+                            if re.search("@", word):
+                                user = word
+
+                                if (user != name):
+
+                                    b = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                                    b.set_title('Follow')
+                                    b.set_value(user)
+                                    b.connect("clicked", self.controller.activeAccount.FollowUser, user)
+                                    vbox0.pack_start(b, expand=False)
+                                    unfollowButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                                    unfollowButton.set_title('unFollow')
+                                    unfollowButton.set_value(user)
+                                    unfollowButton.connect("clicked", self.controller.activeAccount.UnFollowUser, user)
+                                    vbox1.pack_start(unfollowButton, expand=False)
+                                    b2 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+
+                                    b2.set_title(user)
+                                    b2.connect("clicked", self.controller.tweetAtUser, user)
+                                    vbox2.pack_start(b2, expand=False)
+                                    b3 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                      hildon.BUTTON_ARRANGEMENT_VERTICAL)
+
+                                    b3.set_title('History')
+                                    b3.set_value(user)
+                                    b3.connect("clicked", self.controller.showHist, user)
+                                    vbox3.pack_start(b3, expand=False)
+
+
+
+
+        except IndexError:
+            print "nothing selected"
+
+        hbox1.pack_start(vbox0, expand=False)
+        hbox1.pack_start(vbox1, expand=False)
+        hbox1.pack_start(vbox2, expand=False)
+        hbox1.pack_start(vbox3, expand=False)
+        pannedArea.add_with_viewport(hbox1)
+        win.add(pannedArea)
+        win.show_all()
+
+
 
     def scrollToItem(self, item):
         try:
@@ -2027,3 +2148,4 @@ class WitterUI():
 
 
 
+
